The ``as_image_hdu`` option is now available for ``CCDData.to_hdu`` and
``CCDData.write``. This option allows the user to get an ``ImageHDU`` as the
first item of the returned ``HDUList``, instead of the default ``PrimaryHDU``.